<?php
/** 
 * ͸ڡʥХǡ˥ץ륯饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: Index.php,v 1.3 2007/11/19 14:18:03 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class Example2_Index extends AppAction
{
    /**
     * 󥹥ȥ饯
     *
     * @access public
     */
    function Example2_Index()
    {
        // νҤǤޤ
    }

    /**
     * ᥽å
     *
     * @access public
     * @param object ꥯȥ֥
     * @param object ǡ֥
     */
    function execute(&$data, &$context)
    {
        // ե
        // ¥եϡexamples/webapp/lib/Example2Form.php
        $form =& $this->getActionForm($data, 'Example2Form', !$context->isPost());
        if ($context->isPost()) {
            // ϤΥݥȥХå
            if ($form->validate()) {
                $form->setReadOnly(true);
            }
        }
        $data->set('form', $form->getResultArray());
    }

}

?>
